#!perl

use 5.010001;
use strict;
use warnings;
use Test::Exception;
use Test::More 0.98;

use FindBin '$Bin';
use lib "$Bin/lib";

# todo
# use Local::Array::Iterator::Bidirectional;
ok 1;
done_testing;
